api/status.json
Пред. | Глава 6. Web API | След.

## api/status.json

Возвращает информацию о проигрываемой на данный момент композиции. Формат результата аналогичен api/track/info.json. Пример:

    $ curl http://music.tmradio.net/api/track/info.json
    {
      "real_weight": 1.8666666666666667,
      "last_played": 1326743103,
      "weight": 1.8666666666666667,
      "image": null,
      "labels": [ "news", "preroll-not-wanted", "special" ],
      "download": null,
      "id": 4598,
      "count": 5955,
      "filepath": "/radio/music/c/f/cf4970391cb99e64a3b317423d592562.ogg",
      "artist": "Эхо Москвы",
      "title": "Новости",
      "filename": "c/f/cf4970391cb99e64a3b317423d592562.ogg",
      "length": 97
    }

Пред. | Наверх | След.
Глава 6. Web API | Начало | api/track/rocks.json